## CERC Geometry Library

This project is a library with geometry classes with functions built purposely to manipulate geometry representation
of buildings. It has the following classes:
- Plane: has various methods that models a flat surface with no thickness
- Point: contains different methods to manipulate points in 2 and 3 dimensional spaces
- Polygon: contains methods to manipulate different kinds of polygons
- Polyhedron contains a set of methods that manipulate three-dimensional shape with flat polygonal faces